@@ -34,6 +34,8 @@ from openmetadata.api.response import ApiResponse
 from openmetadata.api.utils import jwt_token_secure
 from openmetadata.operations.delete import delete_dag_id
 from openmetadata.operations.deploy import DagDeployer
+from openmetadata.operations.last_dag_logs import last_dag_logs
+from openmetadata.operations.state import disable_dag, enable_dag
 from openmetadata.operations.status import status
 from openmetadata.operations.test_connection import test_source_connection
 from openmetadata.operations.trigger import trigger
@@ -118,6 +120,8 @@ class REST_API(AppBuilderBaseView):
 
         # Deciding which function to use based off the API object that was requested.
         # Some functions are custom and need to be manually routed to.
+        if api == "rest_status":
+            return self.rest_status()
         if api == "deploy_dag":
             return self.deploy_dag()
         if api == "trigger_dag":
@@ -128,17 +132,39 @@ class REST_API(AppBuilderBaseView):
             return self.dag_status()
         if api == "delete_dag":
             return self.delete_dag()
+        if api == "last_dag_logs":
+            return self.last_dag_logs()
+        if api == "enable_dag":
+            return self.enable_dag()
+        if api == "disable_dag":
+            return self.disable_dag()
 
         raise ValueError(
             f"Invalid api param {api}. Expected deploy_dag or trigger_dag."
         )
 
+    @staticmethod
+    def rest_status() -> Response:
+        """
+        Check that the Airflow REST is reachable
+        and running correctly.
+        """
+        try:
+            url = AIRFLOW_WEBSERVER_BASE_URL + REST_API_ENDPOINT
+            return ApiResponse.success(
+                {"message": f"Airflow REST {REST_API_PLUGIN_VERSION} running at {url}"}
+            )
+        except Exception as err:
+            return ApiResponse.error(
+                status=ApiResponse.STATUS_SERVER_ERROR,
+                error=f"Internal error obtaining REST status - {err} - {traceback.format_exc()}",
+            )
+
     def deploy_dag(self) -> Response:
-        """Custom Function for the deploy_dag API
+        """
+        Custom Function for the deploy_dag API
         Creates workflow dag based on workflow dag file and refreshes
         the session
-        args:
-            workflow_config: the workflow config that defines the dag
         """
 
         json_request = request.get_json()
@@ -180,13 +206,13 @@ class REST_API(AppBuilderBaseView):
         except ValidationError as err:
             return ApiResponse.error(
                 status=ApiResponse.STATUS_BAD_REQUEST,
-                error=f"Request Validation Error parsing payload {json_request}. (Workflow)Source expected - {err}",
+                error=f"Request Validation Error parsing payload. (Workflow)Source expected - {err}",
             )
 
         except Exception as err:
             return ApiResponse.error(
                 status=ApiResponse.STATUS_SERVER_ERROR,
-                error=f"Internal error testing connection {json_request} - {err} - {traceback.format_exc()}",
+                error=f"Internal error testing connection {err} - {traceback.format_exc()}",
             )
 
     @staticmethod
@@ -219,6 +245,12 @@ class REST_API(AppBuilderBaseView):
         """
         dag_id: str = self.get_request_arg(request, "dag_id")
 
+        if not dag_id:
+            return ApiResponse.error(
+                status=ApiResponse.STATUS_BAD_REQUEST,
+                error=f"Missing dag_id argument in the request",
+            )
+
         try:
             return status(dag_id)
 
@@ -252,3 +284,67 @@ class REST_API(AppBuilderBaseView):
                 status=ApiResponse.STATUS_SERVER_ERROR,
                 error=f"Failed to delete {dag_id} due to {exc} - {traceback.format_exc()}",
             )
+
+    def last_dag_logs(self) -> Response:
+        """
+        Retrieve all logs from the task instances of a last DAG run
+        """
+        dag_id: str = self.get_request_arg(request, "dag_id")
+
+        if not dag_id:
+            return ApiResponse.error(
+                status=ApiResponse.STATUS_BAD_REQUEST,
+                error=f"Missing dag_id argument in the request",
+            )
+
+        try:
+            return last_dag_logs(dag_id)
+
+        except Exception as exc:
+            logging.info(f"Failed to get last run logs for '{dag_id}'")
+            return ApiResponse.error(
+                status=ApiResponse.STATUS_SERVER_ERROR,
+                error=f"Failed to get last run logs for '{dag_id}' due to {exc} - {traceback.format_exc()}",
+            )
+
+    @staticmethod
+    def enable_dag() -> Response:
+        """
+        Given a DAG ID, mark the dag as enabled
+        """
+        request_json = request.get_json()
+
+        dag_id = request_json.get("dag_id")
+        if not dag_id:
+            return ApiResponse.bad_request(f"Missing dag_id argument in the request")
+
+        try:
+            return enable_dag(dag_id)
+
+        except Exception as exc:
+            logging.info(f"Failed to get last run logs for '{dag_id}'")
+            return ApiResponse.error(
+                status=ApiResponse.STATUS_SERVER_ERROR,
+                error=f"Failed to get last run logs for '{dag_id}' due to {exc} - {traceback.format_exc()}",
+            )
+
+    @staticmethod
+    def disable_dag() -> Response:
+        """
+        Given a DAG ID, mark the dag as disabled
+        """
+        request_json = request.get_json()
+
+        dag_id = request_json.get("dag_id")
+        if not dag_id:
+            return ApiResponse.bad_request(f"Missing dag_id argument in the request")
+
+        try:
+            return disable_dag(dag_id)
+
+        except Exception as exc:
+            logging.info(f"Failed to get last run logs for '{dag_id}'")
+            return ApiResponse.error(
+                status=ApiResponse.STATUS_SERVER_ERROR,
+                error=f"Failed to get last run logs for '{dag_id}' due to {exc} - {traceback.format_exc()}",
+            )
